<?php

session_start();

require_once __DIR__ . '/rbs.php';

class Rbspayment_PaymentSystemDriver extends AMI_PaymentSystemDriver{

    /**
     * Get checkout button HTML form
     *
     * @param array $aRes Will contain "error" (error description, 'Success by default') and "errno" (error code, 0 by default). "forms" will contain a created form
     * @param array $aData The data list for button generation
     * @param bool $bAutoRedirect If form autosubmit required (directly from checkout page)
     * @return bool true if form is generated, false otherwise
     */
    public function getPayButton(&$aRes, $aData, $bAutoRedirect = false){
        $aRes['errno'] = 0;
        $aRes['error'] = 'Success';

        // Format fields
        foreach(Array("return", "description") as $fldName){
            $aData[$fldName] = htmlspecialchars($aData[$fldName]);
        }
        $aData['hiddens'] = $this->getScopeAsFormHiddenFields($aData);

        // Disable to process order using example button
        // $aData["disabled"] = "disabled";
        
        // Set your fields of $aData here

        return parent::getPayButton($aRes, $aData, $bAutoRedirect);
    }
    
    /**
     * Get the form that will be autosubmitted to payment system. This step is required for some shooping cart actions.
     *
     * @param array $aData The data list for button generation
     * @param array $aRes Will contain "error" (error description, 'Success by default') and "errno" (error code, 0 by default). "forms" will contain a created form
     * @return bool true if form is generated, false otherwise
     */
    public function getPayButtonParams($aData, &$aRes){
        // Check parameters and set your fields here
        $aRes['errno'] = 0;
        $aRes['error'] = 'Success';
		
		$user_name = $aData['username'];
		$password = $aData['password'];
		$two_stage = ($aData['two_stage'] == 'true') ? TRUE : FALSE;
		$test_mode = ($aData['test_mode'] == 'true') ? TRUE : FALSE;
		$logging = ($aData['logging'] == 'true') ? TRUE : FALSE;
		
		$rbs = new RBS($user_name, $password, $logging, $two_stage, $test_mode);
		
		$order_number = $aData['order_id'];
		$amount = $aData['amount'] * 100;
		$return_url = 'http://' . $_SERVER['SERVER_NAME'] . '/rbspayment.php';
		
		
		$response = $rbs->register_order($order_number, $amount, $return_url);
		
		if (!isset($response['errorCode'])) {
			$_SESSION[$response['orderId'] . '_number'] = $order_number;
			$_SESSION[$response['orderId'] . '_return'] = $aData['return'];
			$_SESSION[$response['orderId'] . '_cancel'] = $aData['cancel'];
			$_SESSION['user_name'] = $user_name;
			$_SESSION['password'] = $password;
			$_SESSION['logging'] = $logging;
			$_SESSION['test_mode'] = $test_mode;
			$aData['url'] =  $response['formUrl'];
			$aData['order_id'] = $response['orderId'];
			$aData['request_method'] = 'GET';
		} else {
			$aData['url'] = $aData['cancel'];	
		}
		return parent::getPayButtonParams($aData, $aRes);
    }

    /**
     * Verify the order from user back link. In success case 'accepted' status will be setup for order.
     *
     * @param array $aGet $_GET data
     * @param array $aPost $_POST data
     * @param array $aRes reserved array reference
     * @param array $aCheckData Data that provided in driver configuration
     * @return bool true if order is correct and false otherwise
     * @see AMI_PaymentSystemDriver::payProcess(...)
     */
    public function payProcess($aGet, $aPost, &$aRes, $aCheckData){
        // See implplementation of this method in parent class
        
        return parent::payProcess($aGet, $aPost, $aRes, $aCheckData);
    }

    /**
     * Verify the order by payment system background responce. In success case 'confirmed' status will be setup for order.
     *
     * @param array $aGet $_GET data
     * @param array $aPost $_POST data
     * @param array $aRes reserved array reference
     * @param array $aCheckData Data that provided in driver configuration
     * @return int -1 - ignore post, 0 - reject(cancel) order, 1 - confirm order
     * @see AMI_PaymentSystemDriver::payCallback(...)
     */
    public function payCallback($aGet, $aPost, &$aRes, $aCheckData){
        // See implplementation of this method in parent class
		die('3');
        return parent::payProcess($aGet, $aPost, $aRes, $aCheckData);
    }

    /**
     * Return real system order id from data that provided by payment system.
     *
     * @param array $aGet $_GET data
     * @param array $aPost $_POST data
     * @param array $aRes reserved array reference
     * @param array $aAdditionalParams reserved array
     * @return int order Id
     * @see AMI_PaymentSystemDriver::getProcessOrder(...)
     */
    public function getProcessOrder($aGet, $aPost, &$aRes, $aAdditionalParams){
        // See implplementation of this method in parent class
        
        return parent::getProcessOrder($aGet, $aPost, $aRes, $aAdditionalParams);
    }
}
